#
# spec file for package python-qt5
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-qt5
Version:        5.5.1
Release:        7.17
Summary:        PyQt - python bindings for Qt 5
License:        SUSE-GPL-2.0-with-FLOSS-exception or GPL-3.0 or SUSE-NonFree
Group:          Development/Libraries/Python
Url:            http://www.riverbankcomputing.com/software/pyqt/intro
Source:         http://sourceforge.net/projects/pyqt/files/PyQt5/PyQt-5.5.1/PyQt-gpl-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE: DIsable RPATH
Patch1:         disable-rpaths.diff
# PATCH-FIX-UPSTREAM: fix_qreal_check.diff -- check if qreal is double based on sizeof
Patch2:         fix_qreal_check.diff
BuildRequires:  dbus-1-python-devel
BuildRequires:  gdb
BuildRequires:  libQt5WebKit5-devel
BuildRequires:  libQt5WebKitWidgets-devel
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  libqt5-qtdeclarative-devel
BuildRequires:  libqt5-qtmultimedia-devel
BuildRequires:  libqt5-qtserialport-devel
BuildRequires:  libqt5-qtsvg-devel
BuildRequires:  libqt5-qttools-devel
BuildRequires:  libqt5-qtwebchannel-devel
%if 0%{?suse_version} >= 1320
%ifnarch ppc ppc64 ppc64le s390 s390x
BuildRequires:  libqt5-qtwebengine-devel
%endif
%endif
BuildRequires:  libqt5-qtconnectivity-devel
BuildRequires:  libqt5-qtwebsockets-devel
BuildRequires:  libqt5-qtx11extras-devel
BuildRequires:  libqt5-qtxmlpatterns-devel
BuildRequires:  pkg-config
#BuildRequires:  phonon-devel
BuildRequires:  python-devel
BuildRequires:  python-sip-devel >= 4.16.9
%requires_ge    dbus-1-python
%requires_ge    libqt5-x11
%py_requires
%requires_python_sip_api

%description
PyQt is a set of Python bindings for Trolltech's Qt application
framework and runs on all platforms supported by Qt including Windows,
MacOS/X and Linux. There are two sets of bindings: PyQt v5 supports Qt
v5, and it can be co-installed with PyQt4.

%package devel
Summary:        PyQt - devel part of python bindings for Qt 5
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       libQt5WebKit5-devel
Requires:       libQt5WebKitWidgets-devel
Requires:       libqt5-qtbase-devel
Requires:       libqt5-qtdeclarative-devel
Requires:       libqt5-qtsvg-devel
Requires:       libqt5-qttools-devel
Requires:       libqt5-qtx11extras-devel
Requires:       python-qt5-utils
Requires:       python-sip-devel >= 4.16.9
Requires:       update-alternatives

%description devel
PyQt is a set of Python bindings for Trolltech's Qt application
framework and runs on all platforms supported by Qt including Windows,
MacOS/X and Linux. There are two sets of bindings: PyQt v5 supports Qt
v5, and it can be co-installed with PyQt4.

This package contains all the developer tools you need to create your
own PyQt applications.

%package utils
Summary:        Common files for PyQt5 for python2 and python3
Group:          Development/Libraries/Python
Requires:       update-alternatives

%description utils
This package is needed to avoid conflicts between python-qt5 and
python3-qt5 packages. It contains files common to both of them i.e.
sip files used to generate bindings and utilities pylupdate5 and pyrcc5

%prep
%setup -q -n PyQt-gpl-%{version}
#PATCH-FIX-OPENSUSE: Disable RPATH when building PyQt5.
%patch1
%patch2 -p1

%build
export CXXFLAGS="%{optflags}"
export CFLAGS="%{optflags}"
python configure.py --confirm-license --qsci-api -u --qmake %{_libqt5_qmake}

make %{?_smp_mflags}

%install
%make_install INSTALL_ROOT=%{buildroot}

# Alternatives to prevent conflicts

# pyuic5

mv %{buildroot}%{_bindir}/pyuic5 %{buildroot}%{_bindir}/pyuic5-%{py_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/pyuic5
ln -s -f %{_sysconfdir}/alternatives/pyuic5 %{buildroot}/%{_bindir}/pyuic5

#pylupdate5

mv %{buildroot}%{_bindir}/pylupdate5 %{buildroot}%{_bindir}/pylupdate5-%{py_ver}
touch %{buildroot}%{_sysconfdir}/alternatives/pylupdate5
ln -s -f %{_sysconfdir}/alternatives/pylupdate5 %{buildroot}/%{_bindir}/pylupdate5

#pyrcc5

mv %{buildroot}%{_bindir}/pyrcc5 %{buildroot}%{_bindir}/pyrcc5-%{py_ver}
touch %{buildroot}%{_sysconfdir}/alternatives/pyrcc5
ln -s -f %{_sysconfdir}/alternatives/pyrcc5 %{buildroot}/%{_bindir}/pyrcc5

sed -i 's/The "doc" directory/The "doc" directory of package %{name}-devel/' README
DOCDIR=%{buildroot}%{_docdir}/%{name}-devel
mkdir -p $DOCDIR
cp -pr NEWS doc examples $DOCDIR
pushd $DOCDIR
chmod -x `find . -name '*.py*'`
popd

%post devel

update-alternatives --install %{_bindir}/pyuic5 pyuic5 %{_bindir}/pyuic5-%{py_ver} 50
update-alternatives --install %{_bindir}/pylupdate5 pylupdate5 %{_bindir}/pylupdate5-%{py_ver} 50
update-alternatives --install %{_bindir}/pyrcc5 pyrcc5 %{_bindir}/pyrcc5-%{py_ver} 50

%preun devel

if [ "$1" = 0 ] ; then
    update-alternatives --remove pyuic5 %{_bindir}/pyuic5-%{py_ver}
    update-alternatives --remove pyrcc5 %{_bindir}/pyrcc5-%{py_ver}
    update-alternatives --remove pylupdate5 %{_bindir}/pylupdate5-%{py_ver}
fi

%files
%defattr(-,root,root)
%doc README
%{python_sitearch}/PyQt5/
%{python_sitelib}/dbus/mainloop/pyqt5.so
%dir %{_libqt5_plugindir}/PyQt5/
%{_libqt5_plugindir}/PyQt5/libpyqt5qmlplugin.so

%files devel
%defattr(-,root,root)
%attr(755,root,root) %ghost %{_bindir}/pyuic5
%attr(755,root,root) %ghost %{_bindir}/pylupdate5
%attr(755,root,root) %ghost %{_bindir}/pyrcc5
%{_datadir}/qt5/qsci/
%{_docdir}/python-qt5-devel
%{_libqt5_plugindir}/designer/libpyqt5.so
%ghost  %{_sysconfdir}/alternatives/pyuic5
%ghost  %{_sysconfdir}/alternatives/pylupdate5
%ghost  %{_sysconfdir}/alternatives/pyrcc5
%attr(755,root,root) %{_bindir}/pyuic5-%{py_ver}
%attr(755,root,root) %{_bindir}/pylupdate5-%{py_ver}
%attr(755,root,root) %{_bindir}/pyrcc5-%{py_ver}

%files utils
%defattr(-,root,root)
%{_datadir}/sip/PyQt5

%changelog
* Sun Jun  5 2016 hrvoje.senjan@gmail.com
- Drop unused libqt5-qtquick1-devel (Build)Requires
* Mon Mar  7 2016 dvaleev@suse.com
- Don't buildrequire libqt5-qtwebengine-devel for POWER and s390x
* Mon Feb  1 2016 lbeltrame@kde.org
- BuildRequire libqt5-qtconnectivity-devel to gain support for
  QtBluetooth (bnc#964256)
* Fri Oct 30 2015 termim@gmail.com
- Update to 5.5.1
  * added support for Qt v5.5.1
  * added the --disable option to configure.py
  * implemented __matmul__ and __imatmul__ for QMatrix4x4 and
    QTransform.
* Fri Aug 14 2015 termim@gmail.com
- change required sip version to 4.16.9
* Mon Jul 20 2015 termim@gmail.com
- remove patch build-compare.diff as adapted in upstream
- Update to 5.5
  * Added full support for Qt v5.5.0.
  * Added the QtLocation module.
  * Added the QtNfc module.
  * Added Qt.NoOpaqueDetection amd Qt.NoFormatConversion to QtCore.
  * Added QMacToolBar and QMacToolBarItem to QtMacExtras.
  * Added QProxyStyle to QtWidgets.
- Update to 5.4.2
  * Added support for Qt v5.4.2.
  * Added QWIDGETSIZE_MAX to QtWidgets.
  * Added the --no-python-dbus command line option to configure.py.
- Update to 5.4.1
  * Added support for Qt v5.4.1.
  * Added the QMacCocoaViewContainer class.
  * All OpenGL examples use QOpenGLWidget and no longer require
    PyOpenGL.
  * Added initial implementations of _QOpenGLFunctions_2_1 and
    _QOpenGLFunctions_4_1_Core.
  * QEvent.None is now QEvent.None_.
  * Added missing QEvent.Type members that are now documented in Qt.
  * Added the --license-dir option to configure.py.
  * Installing into a virtual env should now work.
  * pyuic5 and pyrcc5 no longer include a timestamp in the
    generated code.
* Fri Jan 16 2015 hrvoje.senjan@gmail.com
- Enable QtWebEngineWidgets and QtWebChannel integration
- Update build-compare.diff
- Drop fdupes usage due to unpredictable symlinking
- Add rpmlintrc due to duplicates waste warnings: we rather have
  a few bytes more than to republish same binaries due to fdupes
* Tue Dec 30 2014 hrvoje.senjan@gmail.com
- Update to 5.4
  * Major functional release that adds full support for Qt v5.4.0.
  * Added the QtWebChannel module
  * Added the QtWebEngineWidgets module
  * Added the QtXml module.
- Drop add_dep.patch, merged upstream
- Bump python(3)-sip-devel (Build)Requires to 4.16.4
* Sat Oct 11 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2
  * Added the Enginio module.
  * Added the QJsonDocument and QJsonValue classes.
  * QJsonObject is implemented as a Python dict.
  * QJsonArray is implemented as a Python list.
  * Added setUnifiedTitleAndToolBarOnMac() and
    unifiedTitleAndToolBarOnMac() to QWidget.
  * Added windowHandle() to QWidget.
- Drop usage of rversion, use version directly
- Disable disable-rpaths.diff, upstream removed RPATH usage in this
  release
* Wed Sep 10 2014 hrvoje.senjan@gmail.com
- Added add_dep.patch: make the buildsystem know that QtPrintSUpport
  module is needed for QtWebkitWidgets one, previously the build
  only succeeded due to QTBUG-39249
* Sun Jul  6 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * minor bug-fix release
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Drop link-python.diff, it's unused
* Thu May 29 2014 hrvoje.senjan@gmail.com
- Update to 5.3
  * By default a Python slot is only invoked if the underlying C++
    instance still exists.
  * Added the no_receiver_check argument to connect().
  * Added support for Qt v5.3.0.
  * Added the QtQuickWidgets module.
  * Added the QtWebSockets module.
  * Added the --target_py_version, --sysroot and --no-tools option
    to configure.py.
  * Cross-compilation (specifically to iOS and Android) is now supported
- Drop qglobal.patch, included in this release
- Added libqt5-qtwebsockets-devel BuildRequires
- Bump required python(3)-sip-devel version to 4.16
* Fri May 16 2014 hrvoje.senjan@gmail.com
- Added qglobal.patch, to resolve build failure with Qt 5.3 API
* Sun May  4 2014 i@marguerite.su
- added missing qtmultimedia/qtserialport/qtxmlpatterns modules.
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1
  * Full support for Qt v5.2.1.
  * Properties, signals and slots can now be defined in mixins
    (i.e. non-QObject classes).
  * Support for creating QSGGeometry.AttributeSet instances.
  * Fundamental values may now be given whenever a QJSValue
    is expected.
  * Building PyQt5 as static libraries now works.
  * Support for building without OpenGL.
- Bump sip BuildRequire to current requirements (4.15.5). Also,
  that is now minimal requires for devel subpackages
- Rebase disable-rpaths.diff for this release
- Disable fix_qreal_check.diff, for now the issue is fixed with
  Qt >= 5.2
- Drop checks for ancient releases
* Thu Feb  6 2014 hrvoje.senjan@gmail.com
- Added fix_qreal_check.diff, fixes build on arm
* Fri Jan 10 2014 lbeltrame@kde.org
- Use %%ghost with files generated by update-alternatives
* Fri Jan 10 2014 lbeltrame@kde.org
- New upstream release 5.2:
  - Full support for Qt5.2
  - Support added for the QtBluetooth, QtPositioning, QtMacExtras,
    QtWinExtras and QtX11Extras
- Fix SNAFU in preun scriptlet (missing spaces)
* Tue Dec 17 2013 hrvoje.senjan@gmail.com
- Move away from pkgconfig(...) BuildRequires and just use
  libqt5-$upstreammodulename-(devel|private-headers-devel)
* Mon Oct 21 2013 hrvoje.senjan@gmail.com
- Fix Requires for the devel packages
* Sun Oct 20 2013 lbeltrame@kde.org
- Use alternatives to prevent conflicts between Python 2 and Python 3
  tools
* Thu Oct 17 2013 toddrme2178@gmail.com
- New upstream release (5.1.1):
  * Bugfixes
- Rebase disable-rpaths.diff
* Sat Oct  5 2013 lbeltrame@kde.org
- New upstream release (5.1):
  * Full support for Qt 5.1
  * Support for QtSensors and QtSerialPort modules
  * Almost complete set of bindings for OpenGL 2.0 and OpenGL ES/2
- Bump required SIP version
* Wed Sep 11 2013 lbeltrame@kde.org
- New upstream release (5.0.1):
  * Added the QtQuick module including the ability to create
    Python Quick items from QML.
  * Added the QtQml module including the ability to create Python objects from
    QML.
  * Added the QtMultimediaWidgets module.
  * Completed the implementation of the QtMultimedia module including support
    for cameras and radios.
  * Added the remaining OpenGL classes to the QtGui module.
  * Added the revision keyword argument to pyqtProperty().
  * Added the revision and arguments keyword arguments to pyqtSignal().
  * Added the revision keyword argument to pyqtSlot().
  * Added the pyqt5qmlplugin plugin for qmlscene.
  * The DBus main loop module has been renamed to dbus.mainloop.pyqt5
    from dbus.mainloop.qt.
  * Added the --no-qml-plugin and --qml-plugindir options to configure.py.
  * Added many QtMultimedia, QML and QtQuick related examples.
  * Classes now support co-operative multi-inheritance. (This may
    introduce incompatibilities with PyQt v5.0.)
- Drop mainloop_rename.diff (merged upstream)
* Tue Aug  6 2013 lbeltrame@kde.org
- Add Patch3 to fix the dbus mainloop lib name (already upstream)
* Mon Aug  5 2013 lbeltrame@kde.org
- Initial package for PyQt5.
